# Faire un multi progressbar en rich

![tag](Rich)
![category](python)

```python
import time
from rich.progress import *

progress_columns = (
    SpinnerColumn(),
    "[progress.description]{task.description}",
    BarColumn(),
    TaskProgressColumn(),
    "Elapsed:",
    TimeElapsedColumn(),
)


with Progress(*progress_columns) as progress:

    task1 = progress.add_task("[red]Downloading...", total=100, start=False)
    task2 = progress.add_task("[green]Processing...", total=100, start=False)
    task3 = progress.add_task("[purple]Processing...", total=None, start=False)
    for task_id in [task1, task2, task3]:
        progress.start_task(task_id)
        i = 0
        while i < 100:
            progress.update(task_id, advance=1)
            i = i+1
            time.sleep(0.1)

```

ou

```python
import time
from rich.progress import *

progress_columns = (
    SpinnerColumn(finished_text =':heavy_check_mark:'),
    "[progress.description]{task.description}",
    BarColumn(),
    TaskProgressColumn(),
    "Elapsed:",
    TimeElapsedColumn(),
)


with Progress(*progress_columns) as progress:

    task1 = progress.add_task("[red]Downloading...", total=100, start=False, visible=False)
    task2 = progress.add_task("[green]Processing...", total=100, start=False, visible=False)
    task3 = progress.add_task("[purple]Processing...", total=None, start=False, visible=False)
    for task_id in [task1, task2, task3]:
        progress.start_task(task_id)
        i = 0
        while i < 100:
            progress.update(task_id, advance=1, visible=True)
            i = i+1
            time.sleep(0.05)
        task = [task for task in progress.tasks if task.id == task_id][0]
        task.total = task.completed
        task.finished_time = task.elapsed
```

ou

```python
import time
from rich.progress import *

progress_columns = (
    "[progress.description]{task.description}",
    BarColumn(),
    TaskProgressColumn(),
    "Elapsed:",
    TimeElapsedColumn(),
)


with Progress(*progress_columns) as progress:

    task1 = progress.add_task("[red]Downloading...", total=100, start=False, visible=True, extra='heavy_check_mark')
    task2 = progress.add_task("[green]Processing...", total=100, start=False, visible=True, extra='heavy_check_mark')
    task3 = progress.add_task("[purple]Processing...", total=None, start=False, visible=True, extra='heavy_check_mark')
    for task_id in [task1, task2, task3]:
        task = [task for task in progress.tasks if task.id == task_id][0]
        progress.update(task_id, advance=1, visible=True, description=":white_medium_square: %s" % task.description)
    for task_id in [task1, task2, task3]:
        task = [task for task in progress.tasks if task.id == task_id][0]
        progress.update(task_id, advance=1, visible=True, description="[blue1]:play_button: %s" % task.description.split(': ')[-1])
        progress.start_task(task_id)
        i = 0
        while i < 100:
            progress.update(task_id, advance=1, visible=True)
            i = i+1
            time.sleep(0.05)
        progress.update(task_id, advance=1, visible=True, description="[green]:heavy_check_mark: %s" % task.description.split(': ')[-1])

#[red]heavy_multiplication_x
```        